"use client";
import React, { useEffect, useRef } from "react";
import Chart from "chart.js/auto";

interface ChartData {
  labels: string[];
  datasets: {
    data: number[];
    label: string;
    borderColor: string;
    backgroundColor: string;
    fill: boolean;
  }[];
}

interface ExampleProps {
  chartData: ChartData;
}

function LineChart(props: ExampleProps) {
  const { chartData } = props;
  const chartRef = useRef<Chart | null>(null);

  useEffect(() => {
    const canvas = document.getElementById(
      "myChart"
    ) as HTMLCanvasElement | null;
    if (canvas) {
      const ctx = canvas?.getContext("2d");
      if (ctx) {
        if (chartRef.current) {
          chartRef.current.destroy();
        }
        chartRef.current = new Chart(ctx, {
          type: "line",
          data: chartData,
        });
      }
    }

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, [chartData]);

  return (
    <div>
      <h1 className="w-[110px] mx-auto mt-10 text-xl font-semibold capitalize ">
        line Chart
      </h1>
      <div className="w-[1100px] h-screen flex mx-auto my-auto">
        <div className="border border-gray-400 pt-0 rounded-xl  w-full h-fit my-auto  shadow-xl">
          <canvas id="myChart"></canvas>
        </div>
      </div>
      </div>
  );
}
export default LineChart;